/***********************************************************************/
/*                                                                     */
/*                              Pio (C++)                              */
/*                                                                     */
/*                    Polyglot Input/Output Library                    */
/*                                                                     */
/*               EPI Pomdapi, INRIA Paris - Rocquencourt               */
/*                                                                     */
/*  Copyright 2005-2014 INRIA.                                         */
/*  Institut National de Recherche en Informatique et en Automatique.  */
/*  All rights reserved. This file is distributed only by permission.  */
/*                                                                     */
/*  Estelle Marchand <Estelle.Marchand@inria.fr>                       */
/*                                                                     */
/***********************************************************************/

/* $Id: receive.hpp,v 1.9 2014/01/10 19:22:09 fclement Exp $ */

#include "single_types.hpp"

#ifndef _RECEIVE_H
#define _RECEIVE_H

using namespace std;

/* See io.mli for the definition of the communication protocol. */


/////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////

namespace io{
  class StringLengthError{};
  class MatrixSizeError{};


  ////////////////
  //************//
  //*TO RECEIVE*//
  //************//
  ////////////////
  template<class typeName> void receive(istream& ib,typeName&);
  //
  void receive_boolean(istream& ,boolean& );
  void receive_string(istream& ,string& );
  void receive_int(istream& ,int& );
  void receive_int_couple(istream& ,int_couple& );
  void receive_int_triple(istream& ,int_triple& );
  void receive_float(istream& ,double& );
  void receive_float_couple(istream& ,float_couple& );
  void receive_float_triple(istream& ,float_triple& );
  void receive_boolean_couple(istream& ,boolean_couple& );
  void receive_boolean_triple(istream& ,boolean_triple& );
  void receive_int_float_couple(istream& ,int_float_couple& );
  void receive_float_int_couple(istream& ,float_int_couple& );
  void receive_int_string_couple(istream& ,int_string_couple& );
  void receive_string_int_couple(istream& ,string_int_couple& );
  void receive_string_float_couple(istream& ,string_float_couple& );
  void receive_float_string_couple(istream& ,float_string_couple& );
  void receive_boolean_vector(istream& ,vector<boolean>& );
  void receive_boolean_couple_vector(istream& , vector<boolean_couple>&);
  void receive_boolean_triple_vector(istream& , vector<boolean_triple>&);
  void receive_string_vector(istream& ,vector<string>& );
  void receive_int_vector(istream& ,vector<int>& );
  void receive_int_couple_vector(istream& , vector<int_couple>&);
  void receive_int_triple_vector(istream& , vector<int_triple>&);
  void receive_float_vector(istream&, vector<double>&);
  void receive_float_couple_vector(istream& ,vector<float_couple>& );
  void receive_float_triple_vector(istream& ,vector<float_triple>& );
  void receive_row_float_matrix(istream& ib,unsigned int& m,unsigned int& n,double* & M);
  void receive_row_float_matrix(istream& ib,unsigned int& m,unsigned int& n,double** & M);
  void receive_column_float_matrix(istream& ib,unsigned int& m,unsigned int& n,double* & M);
  void receive_column_float_matrix(istream& ib,unsigned int& m,unsigned int& n,double** & M);
  //
  boolean receive_boolean(istream& ib);
  boolean_couple receive_boolean_couple(istream& ib);
  boolean_triple receive_boolean_triple(istream& ib);
  string receive_string(istream& ib);
  int receive_int(istream& ib);
  int_couple receive_int_couple(istream& ib);
  int_triple receive_int_triple(istream& ib);
  double receive_float(istream& ib);
  float_couple receive_float_couple(istream& ib);
  float_triple receive_float_triple(istream& ib);
  vector<boolean> receive_boolean_vector(istream& ib);
  vector<boolean_couple> receive_boolean_couple_vector(istream& ib);
  vector<boolean_triple> receive_boolean_triple_vector(istream& ib);
  vector<string> receive_string_vector(istream& ib);
  vector<int> receive_int_vector(istream& ib);
  vector<double> receive_float_vector(istream& ib);
  vector<float_couple> receive_float_couple_vector(istream& ib);
  vector<float_triple> receive_float_triple_vector(istream& ib);
  vector<int_couple> receive_int_couple_vector(istream& ib);
  vector<int_triple> receive_int_triple_vector(istream& ib);
  //
  void receive_row_from_row_float_matrix(istream& ib,unsigned int& m,unsigned int& n,double* & M);
  void receive_row_from_column_float_matrix(istream& ib,unsigned int& m,unsigned int& n,double* & M);
  void receive_column_from_row_float_matrix(istream& ib,unsigned int& m,unsigned int& n,double* & M);
  void receive_column_from_column_float_matrix(istream& ib,unsigned int& m,unsigned int& n,double* & M);
  void receive_float_array(istream& ib,unsigned int& n,double*& M);


  ///
 

 
}


#endif

