/***********************************************************************/
/*                                                                     */
/*                            Pio (Fortran)                            */
/*                                                                     */
/*                    Polyglot Input/Output Library                    */
/*                                                                     */
/*               EPI Pomdapi, INRIA Paris - Rocquencourt               */
/*                                                                     */
/*  Copyright 2005-2014 INRIA.                                         */
/*  Institut National de Recherche en Informatique et en Automatique.  */
/*  All rights reserved. This file is distributed only by permission.  */
/*                                                                     */
/*  Francois Clement <Francois.Clement@inria.fr>                       */
/*  Pierre Weis <Pierre.Weis@inria.fr>                                 */
/*  Hend Ben Ameur <hbenameur@yahoo.ca>                                */
/*                                                                     */
/***********************************************************************/

/* $Id: flush.c,v 1.9 2014/01/10 19:22:10 fclement Exp $ */

/* #include <unistd.h> */
#include <stdlib.h>
#include <stdio.h>
#include <errno.h>
#include "pio_constants.h"

void flush_error(int oc) {
  char *fd, *file;
  extern int errno;
  
  fd = "";
  file = "";
  
  sprintf(fd, "Fortran file descriptor %d", oc);
  sprintf(file, "file associated to the %s", fd);
  
  if (errno == EBADF)
    fprintf(stderr, "%s is neither valid nor open for writing.", fd);
  else if (errno == EINVAL)
    fprintf(stderr, "%s is unsuitable for writing.", fd);
  else if (errno == EFAULT)
    fprintf(stderr, "Attempt to access data outside valid space.");
  else if (errno == EFBIG)
    fprintf(stderr, "Attempt to write off limits on %s.", fd);
  else if (errno == EPIPE)
    fprintf(stderr,
            "%s is connected to a pipe or socket whose reading end is closed.",
            fd);
  else if (errno == EAGAIN)
    fprintf(stderr,
            "Non-blocking I/O selection for a blocking write on %s.",
            fd);
  else if (errno == EINTR)
    fprintf(stderr, "Interruption by a signal while writing on the %s.", fd);
  else if (errno == ENOSPC)
    fprintf(stderr, "No space left on the device containing the %s.", file);
  else if (errno == EIO)
    fprintf(stderr,
            "Low-level I/O error while modifying the inode of the %s.",
            file);
  
  exit(PIO_FLUSH_ERROR);
}

void flush_(int oc) {
  int ret_code;
  
  if (oc == PIO_STDOUT)
    ret_code = fflush(stdout);
  else if (oc == PIO_STDERR)
    ret_code = fflush(stderr);
  else if (oc == PIO_STDIN)
    ret_code = fflush(stdin);
  else
    ret_code = 0;
  
  if (ret_code == EOF) flush_error(oc);
}
