/***********************************************************************/
/*                                                                     */
/*                            Pio (Fortran)                            */
/*                                                                     */
/*                    Polyglot Input/Output Library                    */
/*                                                                     */
/*               EPI Pomdapi, INRIA Paris - Rocquencourt               */
/*                                                                     */
/*  Copyright 2005-2014 INRIA.                                         */
/*  Institut National de Recherche en Informatique et en Automatique.  */
/*  All rights reserved. This file is distributed only by permission.  */
/*                                                                     */
/*  Francois Clement <Francois.Clement@inria.fr>                       */
/*  Pierre Weis <Pierre.Weis@inria.fr>                                 */
/*  Hend Ben Ameur <hbenameur@yahoo.ca>                                */
/*                                                                     */
/***********************************************************************/

/* $Id: pio_constants.h,v 1.13 2014/03/14 18:51:24 fclement Exp $ */

#ifndef _PIO_CONSTANTS_H_
#define _PIO_CONSTANTS_H_

#define KIBI 1024
#define MEBI (KIBI * KIBI)

#define ASCII0 48
#define ASCII9 (ASCII0 + 9)

/* Fortran bound constants. */
#define PIO_STDIN 5
#define PIO_STDOUT 6
#define PIO_STDERR 0
#define PIO_IOUNIT 11
#define PIO_DEBUG PIO_STDERR
#define PIO_REPORT PIO_DEBUG

/* PIO_IN is for the incoming communication
   and PIO_OUT for the outgoing communication. */
#define PIO_IN 1
#define PIO_OUT 2

#define INVALID_NATURAL -1
#define INVALID_SUCCESSOR -2
#define INVALID_SUCCESSOR2 -3

#define INVALID_POINTER INVALID_NATURAL
#define INVALID_LIMIT INVALID_SUCCESSOR
#define FIRST_POINTER 1

#include "pio_configurable_constants.h"

#define FLOAT real*FLOAT_SIZE

#if FLOAT_SIZE == 4
#  define PIO_FLOAT_SUFFIX e0
#  define PIO_FLOAT_OF_INT real
#endif
#if FLOAT_SIZE == 8
#  define PIO_FLOAT_SUFFIX d0
#  define PIO_FLOAT_OF_INT dble
#endif

#define INT_OF_FLOAT int

/* Min and max locations in the buffers. */
#define MIN_BUFFER_LOCATION FIRST_POINTER
#define MAX_BUFFER_LOCATION (MIN_BUFFER_LOCATION + BUFFER_SIZE - 1)

/* Maximal size of a character string in characters. */
#define MAX_STRING_LENGTH BUFFER_SIZE

/* Min and max locations in the memory. */
#define MIN_MEMORY_LOCATION FIRST_POINTER
#define MAX_MEMORY_LOCATION (MIN_MEMORY_LOCATION + MEMORY_SIZE - 1)

#include "pio_type_constants.h"
#include "pio_memory_mapping_constants.h"
#include "pio_error_codes.h"

#endif
