(***********************************************************************)
(*                                                                     *)
(*                              Ref-indic                              *)
(*                                                                     *)
(*                        Refinement indicators                        *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright (c) 2013-2014 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: configuration.mli,v 1.19 2014/06/10 15:08:34 fclement Exp $ *)

open Refinement_types;;
open Display_types;;

type t = Configuration_types.t;;

(** {6 Uhistory.Make functor API} *)

val print : t Format_printer.printer;;

val cold_set : unit -> unit;;
val warm_set : t -> unit;;
val get : unit -> t;;

val phase_dimension : Ucommand_option.phase_name;;

(** {6 Algorithm configuration} *)

val get_external_program_command : unit -> external_program_command;;
val get_dimension : unit -> dimension;;
val get_dimension_management : unit -> dimension_management;;
val get_cutting_strategy : unit -> cutting_strategy;;
val get_candidate_cuttings_selection_criterion :
  unit -> candidate_cuttings_selection_criterion
;;
val get_minimum_gradient : unit -> minimum_gradient;;
val get_stopping_criterion : unit -> stopping_criterion;;

(** {6 Program configuration} *)

val get_formatter : unit -> Format.formatter;;
val get_report_allocated_memory : unit -> bool;;
val get_incremental_mode : unit -> bool;;
val get_graphics_mode : unit -> graphics_mode;;
val get_graphics_window_min_size : unit -> size;;
val get_graphics_window_max_size : unit -> size;;
val get_graphics_parameter_color_mapping : unit -> Colormapping.t;;
val get_graphics_gradient_color_mapping : unit -> Colormapping.t;;

(** {6 Monitoring} *)

val report : Upervasives.message -> unit;;
val debug : Upervasives.function_name -> Upervasives.message -> unit;;
val warning : Upervasives.function_name -> Upervasives.message -> unit;;
val error : Upervasives.function_name -> Upervasives.message -> unit;;

val report_action : Upervasives.gen_message -> unit;;
val debug_action :
  Upervasives.function_name -> Upervasives.gen_message -> unit
;;
val warning_action :
  Upervasives.function_name -> Upervasives.gen_message -> unit
;;
val error_action :
  Upervasives.function_name -> Upervasives.gen_message -> unit
;;

val print_ident_value : string -> ('a, 'a) Format_printer.printer_lifter;;

val print_report : ('a, 'a) Format_printer.printer_lifter;;
val print_debug :
  Upervasives.function_name -> string ->
  ('a, 'a) Format_printer.printer_lifter
;;
val print_debug_no_arg :
  Upervasives.function_name ->
  (Format.formatter -> unit) -> Format.formatter -> unit
;;
