(***********************************************************************)
(*                                                                     *)
(*                              Ref-indic                              *)
(*                                                                     *)
(*                        Refinement indicators                        *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright (c) 2013-2014 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: parameter.ml,v 1.5 2014/05/06 12:56:21 fclement Exp $ *)

module Nat = Unatural;;

module Set = Umatrix_nonempty_set;;
module Mapping = Umatrix_graph;;

open Refinement_types;;

let same_geometry = Mapping.same_domain;;

(* Converters. *)

let sub f p map =
  let dom = map.Mapping.domain in
  let ff =
    match map.Mapping.images with
    | Mapping.Constant y ->
        (fun _idx uidx ->
          f (Mapping.image p (Set.full_index_of_uindex uidx)) y)
    | Mapping.Images _ ->
        (fun idx uidx ->
          f
            (Mapping.image p (Set.full_index_of_uindex uidx))
            (Mapping.image map idx)) in
  Mapping.from_fun dom ff
;;

(* Iterators. *)

let map = Mapping.map_images;;

let bounds_of_domain dom =
  let box { ll = (imin, jmin); ur = (imax, jmax); } idx _ =
    let (i, j) = Set.element dom idx in
    { ll = (min i imin, min j jmin); ur = (max i imax, max j jmax); } in
  let (idx, _) = Set.choice dom in
  let pt = Set.element dom idx in
  Set.fold_left box { ll = pt; ur = pt; } dom
;;
