CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C                            Pio (Fortran)                            C
C                                                                     C
C                    Polyglot Input/Output Library                    C
C                                                                     C
C               EPI Pomdapi, INRIA Paris - Rocquencourt               C
C                                                                     C
C  Copyright 2005-2014 INRIA.                                         C
C  Institut National de Recherche en Informatique et en Automatique.  C
C  All rights reserved. This file is distributed only by permission.  C
C                                                                     C
C  Francois Clement <Francois.Clement@inria.fr>                       C
C  Pierre Weis <Pierre.Weis@inria.fr>                                 C
C  Hend Ben Ameur <hbenameur@yahoo.ca>                                C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

C $Id: pio_type_predicates.fpp,v 1.4 2014/03/07 19:21:42 fclement Exp $

#include "pio_constants.h"
      
C     
C     Predicates on Pio typed value types.
C     
      
      logical function is_string_in_type(typ)
C     Is scanning for string values?
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variable.
      integer item_typ
      
      item_typ = MAKE_SCALAR_SIMPLE_ITEM_TYPE(typ)
      is_string_in_type = item_typ .eq. SSTRING
      
      return
      end
      
      
      logical function is_int_in_type(typ)
C     Is scanning for integer values?
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variable.
      integer item_typ
      
      item_typ = MAKE_SCALAR_SIMPLE_ITEM_TYPE(typ)
      is_int_in_type = item_typ .eq. SINT
      
      return
      end
      
      
      logical function is_float_in_type(typ)
C     Is scanning for float values?
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variable.
      integer item_typ
      
      item_typ = MAKE_SCALAR_SIMPLE_ITEM_TYPE(typ)
      is_float_in_type = item_typ .eq. SFLOAT
      
      return
      end
      
      
      logical function is_scalar_simple_string_type(typ)
C     Is type scalar, and simple, and string?
      
      implicit none
      
C     Input argument.
      integer typ
      
      is_scalar_simple_string_type = typ .eq. SSTRING
      
      return
      end
      
      
      logical function is_scalar_simple_int_type(typ)
C     Is type scalar, and simple, and int?
      
      implicit none
      
C     Input argument.
      integer typ
      
      is_scalar_simple_int_type = typ .eq. SINT
      
      return
      end
      
      
      logical function is_scalar_simple_float_type(typ)
C     Is type scalar, and simple, and float?
      
      implicit none
      
C     Input argument.
      integer typ
      
      is_scalar_simple_float_type = typ .eq. SFLOAT
      
      return
      end
      
      
      logical function is_scalar_simple_type(typ)
C     Is type scalar and simple?
      
      implicit none
      
C     Input argument.
      integer typ
      
      is_scalar_simple_type =
     +     (typ .ge. FIRST_SCALAR_SIMPLE_TYPE) .and.
     +     (typ .le. LAST_SCALAR_SIMPLE_TYPE)
      
      return
      end
      
      
      logical function is_scalar_couple_type(typ)
C     Is type scalar and couple?
      
      implicit none
      
C     Input argument.
      integer typ
      
      is_scalar_couple_type =
     +     (typ .ge. FIRST_SCALAR_COUPLE_TYPE) .and.
     +     (typ .le. LAST_SCALAR_COUPLE_TYPE)
      
      return
      end
      
      
      logical function is_scalar_triple_type(typ)
C     Is type scalar and triple?
      
      implicit none
      
C     Input argument.
      integer typ
      
      is_scalar_triple_type =
     +     (typ .ge. FIRST_SCALAR_TRIPLE_TYPE) .and.
     +     (typ .le. LAST_SCALAR_TRIPLE_TYPE)
      
      return
      end
      
      
      logical function is_scalar_tuple_type(typ)
C     Is type scalar and tuple?
      
      implicit none
      
C     Input argument.
      integer typ
      
C     External functions.
      logical is_scalar_couple_type
      logical is_scalar_triple_type
      
      is_scalar_tuple_type =
     +     is_scalar_couple_type(typ) .or.
     +     is_scalar_triple_type(typ)
      
      return
      end
      
      
      logical function is_scalar_type(typ)
C     Is type scalar?
      
      implicit none
      
C     Input argument.
      integer typ
      
C     External functions.
      logical is_scalar_simple_type
      logical is_scalar_tuple_type
      
      is_scalar_type =
     +     is_scalar_simple_type(typ) .or.
     +     is_scalar_tuple_type(typ)
      
      return
      end
      
      
      logical function is_simple_type(typ)
C     Is type simple?
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variable.
      integer item_typ
      
C     External function.
      logical is_scalar_simple_type
      
      item_typ = MAKE_SCALAR_ITEM_TYPE(typ)
      is_simple_type = is_scalar_simple_type(item_typ)
      
      return
      end
      
      
      logical function is_couple_type(typ)
C     Is type couple?
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variable.
      integer item_typ

C     External function.
      logical is_scalar_couple_type
      
      item_typ = MAKE_SCALAR_ITEM_TYPE(typ)
      is_couple_type = is_scalar_couple_type(item_typ)
      
      return
      end
      
      
      logical function is_triple_type(typ)
C     Is type triple?
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variable.
      integer item_typ
      
C     External function.
      logical is_scalar_triple_type
      
      item_typ = MAKE_SCALAR_ITEM_TYPE(typ)
      is_triple_type = is_scalar_triple_type(item_typ)
      
      return
      end
      
      
      logical function is_tuple_type(typ)
C     Is type tuple?
      
      implicit none
      
C     Input argument.
      integer typ
      
C     Local variable.
      integer item_typ
      
C     External function.
      logical is_scalar_tuple_type
      
      item_typ = MAKE_SCALAR_ITEM_TYPE(typ)
      is_tuple_type = is_scalar_tuple_type(item_typ)
      
      return
      end
      
      
      logical function is_vector_simple_type(typ)
C     Is type vector and simple?
      
      implicit none
      
C     Input argument.
      integer typ
      
      is_vector_simple_type =
     +     (typ .ge. FIRST_VECTOR_SIMPLE_TYPE) .and.
     +     (typ .le. LAST_VECTOR_SIMPLE_TYPE)
      
      return
      end
      
      
      logical function is_vector_couple_type(typ)
C     Is type vector and couple?
      
      implicit none
      
C     Input argument.
      integer typ
      
      is_vector_couple_type =
     +     (typ .ge. FIRST_VECTOR_COUPLE_TYPE) .and.
     +     (typ .le. LAST_VECTOR_COUPLE_TYPE)
      
      return
      end
      
      
      logical function is_vector_triple_type(typ)
C     Is type vector and triple?
      
      implicit none
      
C     Input argument.
      integer typ
      
      is_vector_triple_type =
     +     (typ .ge. FIRST_VECTOR_TRIPLE_TYPE) .and.
     +     (typ .le. LAST_VECTOR_TRIPLE_TYPE)
      
      return
      end
      
      
      logical function is_vector_type(typ)
C     Is type vector?
      
      implicit none
      
C     Input argument.
      integer typ
      
C     External functions.
      logical is_vector_simple_type
      logical is_vector_couple_type
      logical is_vector_triple_type
      
      is_vector_type =
     +     is_vector_simple_type(typ) .or.
     +     is_vector_couple_type(typ) .or.
     +     is_vector_triple_type(typ)
      
      return
      end
      
      
      logical function is_multi_d_simple_type(typ)
C     Is type multi-dimensional and simple?
      
      implicit none
      
C     Input argument.
      integer typ
      
      is_multi_d_simple_type =
     +     (typ .ge. FIRST_MULTI_D_SIMPLE_TYPE) .and.
     +     (typ .le. LAST_MULTI_D_SIMPLE_TYPE)
      
      return
      end
      
      
      logical function is_multi_d_couple_type(typ)
C     Is type multi-dimensional and couple?
      
      implicit none
      
C     Input argument.
      integer typ
      
      is_multi_d_couple_type =
     +     (typ .ge. FIRST_MULTI_D_COUPLE_TYPE) .and.
     +     (typ .le. LAST_MULTI_D_COUPLE_TYPE)
      
      return
      end
      
      
      logical function is_multi_d_triple_type(typ)
C     Is type multi-dimensional and triple?
      
      implicit none
      
C     Input argument.
      integer typ
      
      is_multi_d_triple_type =
     +     (typ .ge. FIRST_MULTI_D_TRIPLE_TYPE) .and.
     +     (typ .le. LAST_MULTI_D_TRIPLE_TYPE)
      
      return
      end
      
      
      logical function is_multi_d_type(typ)
C     Is type multi-dimensional?
      
      implicit none
      
C     Input argument.
      integer typ
      
C     External functions.
      logical is_multi_d_simple_type
      logical is_multi_d_couple_type
      logical is_multi_d_triple_type
      
      is_multi_d_type =
     +     is_multi_d_simple_type(typ) .or.
     +     is_multi_d_couple_type(typ) .or.
     +     is_multi_d_triple_type(typ)
      
      return
      end
      
      
      logical function is_array_type(typ)
C     Is type array type?
      
      implicit none
      
C     Input argument.
      integer typ
      
C     External functions.
      logical is_vector_type, is_multi_d_type
      
      is_array_type = is_vector_type(typ) .or. is_multi_d_type(typ)
      
      return
      end
      
      
      logical function is_ascii_float(typ)
C     Is scanning for ascii float values?
      
      implicit none
      
C     Input argument.
      integer typ
      
C     External functions.
      logical is_float_in_type, encoding_mode_is_binary
      
      is_ascii_float =
     +     (.not. (encoding_mode_is_binary())) .and.
     +     (is_float_in_type(typ))
      
      return
      end
      
      
      logical function is_simple_ascii_float(typ)
C     Is scanning for simple ascii float values?
      
      implicit none
      
C     Input argument.
      integer typ
      
C     External functions.
      logical is_scalar_simple_type, is_ascii_float
      
      is_simple_ascii_float =
     +     (is_scalar_simple_type(typ)) .and.
     +     (is_ascii_float(typ))
      
      return
      end
      
      
C     
C     Predicates on Pio communication types.
C     
      
      logical function pio_is_communication_phrase(tc)
C     Is communication phrase?
      
      implicit none
      
C     Input argument.
      integer tc
      
      pio_is_communication_phrase = tc .eq. PIO_PHRASE
      
      return
      end
      
      
      logical function pio_is_communication_task(tc)
C     Is communication task?
      
      implicit none
      
C     Input argument.
      integer tc
      
      pio_is_communication_task = tc .eq. PIO_TASK
      
      return
      end
      
      
      logical function pio_is_communication_result(tc)
C     Is communication result?
      
      implicit none
      
C     Input argument.
      integer tc
      
      pio_is_communication_result = tc .eq. PIO_RESULT
      
      return
      end
      
      
      logical function pio_is_communication_error(tc)
C     Is communication error?
      
      implicit none
      
C     Input argument.
      integer tc
      
      pio_is_communication_error = tc .eq. PIO_ERROR
      
      return
      end
      
      
      logical function pio_is_communication_service(tc)
C     Is communication service?
      
      implicit none
      
C     Input argument.
      integer tc
      
      pio_is_communication_service = tc .eq. PIO_SERVICE
      
      return
      end
      
      
      logical function pio_is_communication(tc)
C     Is communication?
      
      implicit none
      
C     Input argument.
      integer tc
      
C     External functions.
      logical pio_is_communication_phrase, pio_is_communication_task
      logical pio_is_communication_result, pio_is_communication_error
      logical pio_is_communication_service
      
      pio_is_communication =
     +     pio_is_communication_phrase(tc) .or.
     +     pio_is_communication_task(tc) .or.
     +     pio_is_communication_result(tc) .or.
     +     pio_is_communication_error(tc) .or.
     +     pio_is_communication_service(tc)
      
      return
      end
      
      
C     
C     Predicates on Pio service names.
C     
      
      logical function pio_is_service_ok(len, sname)
C     Is service Ok?
      
      implicit none
      
C     Input arguments.
      character sname*PIO_MAX_IDENT_LENGTH
      integer len
      
      pio_is_service_ok =
     +     (len .eq. PIO_SERVICE_OK_LENGTH) .and.
     +     (sname(1:len) .eq. PIO_SERVICE_OK)
      
      return
      end
      
      
      logical function pio_is_service_ko(len, sname)
C     Is service Ko?
      
      implicit none
      
C     Input arguments.
      character sname*PIO_MAX_IDENT_LENGTH
      integer len
      
      pio_is_service_ko =
     +     (len .eq. PIO_SERVICE_KO_LENGTH) .and.
     +     (sname(1:len) .eq. PIO_SERVICE_KO)
      
      return
      end
      
      
      logical function pio_is_service_allo(len, sname)
C     Is service Allo?
      
      implicit none
      
C     Input arguments.
      character sname*PIO_MAX_IDENT_LENGTH
      integer len
      
      pio_is_service_allo =
     +     (len .eq. PIO_SERVICE_ALLO_LENGTH) .and.
     +     (sname(1:len) .eq. PIO_SERVICE_ALLO)
      
      return
      end
      
      logical function pio_is_service_bye(len, sname)
C     Is service Bye?
      
      implicit none
      
C     Input arguments.
      character sname*PIO_MAX_IDENT_LENGTH
      integer len
      
      pio_is_service_bye =
     +     (len .eq. PIO_SERVICE_BYE_LENGTH) .and.
     +     (sname(1:len) .eq. PIO_SERVICE_BYE)
      
      return
      end
      
      
      logical function pio_is_service_start(len, sname)
C     Is service Start?
      
      implicit none
      
C     Input arguments.
      character sname*PIO_MAX_IDENT_LENGTH
      integer len
      
      pio_is_service_start =
     +     (len .eq. PIO_SERVICE_START_LENGTH) .and.
     +     (sname(1:len) .eq. PIO_SERVICE_START)
      
      return
      end
      
      
      logical function pio_is_service_stop(len, sname)
C     Is service Stop?
      
      implicit none
      
C     Input arguments.
      character sname*PIO_MAX_IDENT_LENGTH
      integer len
      
      pio_is_service_stop =
     +     (len .eq. PIO_SERVICE_STOP_LENGTH) .and.
     +     (sname(1:len) .eq. PIO_SERVICE_STOP)
      
      return
      end
      
      
      logical function pio_is_service(len, sname)
C     Is service?
      
      implicit none
      
C     Input arguments.
      character sname*PIO_MAX_IDENT_LENGTH
      integer len
      
C     External functions.
      logical pio_is_service_ok, pio_is_service_ko
      logical pio_is_service_allo, pio_is_service_bye
      logical pio_is_service_start, pio_is_service_stop
      
      pio_is_service =
     +     pio_is_service_ok(len, sname) .or.
     +     pio_is_service_ko(len, sname) .or.
     +     pio_is_service_allo(len, sname) .or.
     +     pio_is_service_bye(len, sname) .or.
     +     pio_is_service_start(len, sname) .or.
     +     pio_is_service_stop(len, sname)
      
      return
      end
